'X-Content-Type-Options: nosniff' header should be implemented which
allows a web server to force the browser into disabling MIME Sniffing
for a served file. The nosniff option will only load any external resource
if the content-type maches what is expected of the file type.